<?php

namespace Vote\Vote\Policies;

use Litepie\User\Contracts\UserPolicy;
use Vote\Vote\Models\Vote;

class VotePolicy
{

    /**
     * Determine if the given user can view the vote.
     *
     * @param UserPolicy $user
     * @param Vote $vote
     *
     * @return bool
     */
    public function view(UserPolicy $user, Vote $vote)
    {
        if ($user->canDo('vote.vote.view') && $user->isAdmin()) {
            return true;
        }

        return $vote->user_id == user_id() && $vote->user_type == user_type();
    }

    /**
     * Determine if the given user can create a vote.
     *
     * @param UserPolicy $user
     * @param Vote $vote
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('vote.vote.create');
    }

    /**
     * Determine if the given user can update the given vote.
     *
     * @param UserPolicy $user
     * @param Vote $vote
     *
     * @return bool
     */
    public function update(UserPolicy $user, Vote $vote)
    {
        if ($user->canDo('vote.vote.edit') && $user->isAdmin()) {
            return true;
        }

        return $vote->user_id == user_id() && $vote->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given vote.
     *
     * @param UserPolicy $user
     * @param Vote $vote
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Vote $vote)
    {
        return $vote->user_id == user_id() && $vote->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given vote.
     *
     * @param UserPolicy $user
     * @param Vote $vote
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Vote $vote)
    {
        if ($user->canDo('vote.vote.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given vote.
     *
     * @param UserPolicy $user
     * @param Vote $vote
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Vote $vote)
    {
        if ($user->canDo('vote.vote.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
