<?php

namespace Vote\Vote\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Vote\Vote\Models\Vote;

class VoteAction
{
    /**
     * Perform the complete action.
     *
     * @param Vote $vote
     *
     * @return Vote
     */
    public function complete(Vote $vote)
    {
        try {
            $vote->status = 'complete';
            return $vote->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Vote $vote
     *
     * @return Vote
     */public function verify(Vote $vote)
    {
        try {
            $vote->status = 'verify';
            return $vote->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Vote $vote
     *
     * @return Vote
     */public function approve(Vote $vote)
    {
        try {
            $vote->status = 'approve';
            return $vote->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Vote $vote
     *
     * @return Vote
     */public function publish(Vote $vote)
    {
        try {
            $vote->status = 'publish';
            return $vote->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Vote $vote
     *
     * @return Vote
     */
    public function archive(Vote $vote)
    {
        try {
            $vote->status = 'archive';
            return $vote->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Vote $vote
     *
     * @return Vote
     */
    public function unpublish(Vote $vote)
    {
        try {
            $vote->status = 'unpublish';
            return $vote->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
