<?php

namespace Vote\Vote\Workflow;

use Vote\Vote\Models\Vote;
use Validator;

class VoteValidator
{

    /**
     * Determine if the given vote is valid for complete status.
     *
     * @param Vote $vote
     *
     * @return bool / Validator
     */
    public function complete(Vote $vote)
    {
        return Validator::make($vote->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given vote is valid for verify status.
     *
     * @param Vote $vote
     *
     * @return bool / Validator
     */
    public function verify(Vote $vote)
    {
        return Validator::make($vote->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given vote is valid for approve status.
     *
     * @param Vote $vote
     *
     * @return bool / Validator
     */
    public function approve(Vote $vote)
    {
        return Validator::make($vote->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given vote is valid for publish status.
     *
     * @param Vote $vote
     *
     * @return bool / Validator
     */
    public function publish(Vote $vote)
    {
        return Validator::make($vote->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given vote is valid for archive status.
     *
     * @param Vote $vote
     *
     * @return bool / Validator
     */
    public function archive(Vote $vote)
    {
        return Validator::make($vote->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given vote is valid for unpublish status.
     *
     * @param Vote $vote
     *
     * @return bool / Validator
     */
    public function unpublish(Vote $vote)
    {
        return Validator::make($vote->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
